summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/widgets/tqradiobutton.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-07-17 19:19:26 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-07-17 19:19:26 -0500
commit33d3ec06354d07cbb6164eb1c8adbd89c9ecefdd (patch)
tree4939d6567b50d0dd669257422a6868aa1259e62b /tqtinterface/qt4/src/widgets/tqradiobutton.cpp
parentf01eee0362e54f47d0266295c5263790c04b6510 (diff)
downloadexperimental-33d3ec06354d07cbb6164eb1c8adbd89c9ecefdd.tar.gz
experimental-33d3ec06354d07cbb6164eb1c8adbd89c9ecefdd.zip
Revert "Rename tqsize* to size*"
This reverts commit e33879600503bacc0b4ef090f7f79ab80bb6b0da.
Diffstat (limited to 'tqtinterface/qt4/src/widgets/tqradiobutton.cpp')
-rw-r--r--tqtinterface/qt4/src/widgets/tqradiobutton.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tqtinterface/qt4/src/widgets/tqradiobutton.cpp b/tqtinterface/qt4/src/widgets/tqradiobutton.cpp
index 0ddddf8..69bdedb 100644
--- a/tqtinterface/qt4/src/widgets/tqradiobutton.cpp
+++ b/tqtinterface/qt4/src/widgets/tqradiobutton.cpp
@@ -156,17 +156,17 @@ void TQRadioButton::setChecked( bool check )
/*!
\reimp
*/
-TQSize TQRadioButton::sizeHint() const
+TQSize TQRadioButton::tqsizeHint() const
{
// Any more complex, and we will use tqstyle().tqitemRect()
// NB: TQCheckBox::sizeHint() is similar
constPolish();
TQPainter p(this);
TQSize sz = tqstyle().tqitemRect(&p, TQRect(0, 0, 1, 1), TQt::ShowPrefix, FALSE,
pixmap(), text()).size();
- return (tqstyle().sizeFromContents(TQStyle::CT_RadioButton, this, sz).
+ return (tqstyle().tqsizeFromContents(TQStyle::CT_RadioButton, this, sz).
expandedTo(TQApplication::globalStrut()));
}
@@ -321,7 +321,7 @@ void TQRadioButton::resizeEvent( TQResizeEvent* e )
TQPainter p(this);
TQSize isz = tqstyle().tqitemRect(&p, TQRect(0, 0, 1, 1), TQt::ShowPrefix, FALSE,
pixmap(), text()).size();
- TQSize wsz = (tqstyle().sizeFromContents(TQStyle::CT_RadioButton, this, isz).
+ TQSize wsz = (tqstyle().tqsizeFromContents(TQStyle::CT_RadioButton, this, isz).
expandedTo(TQApplication::globalStrut()));
update(wsz.width(), isz.width(), 0, wsz.height());
@@ -156,17 +156,17 @@ void TQRadioButton::setChecked( bool check )
{
// Any more complex, and we will use tqstyle().tqitemRect()
- // NB: TQCheckBox::sizeHint() is similar
+ // NB: TQCheckBox::tqsizeHint() is similar
constPolish();
TQPainter p(this);